Module: Google::Cloud::ConfigDelivery

Defined in:
lib/google/cloud/config_delivery.rb,
lib/google/cloud/config_delivery/version.rb

Constant Summary collapse

VERSION =
"0.3.0"

Class Method Summary collapse

Class Method Details

.config_delivery(version: :v1, &block) ⇒ ::Object

Create a new client object for ConfigDelivery.

By default, this returns an instance of Google::Cloud::ConfigDelivery::V1::ConfigDelivery::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ConfigDelivery service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

Raises an exception if the currently installed versioned client gem for the given API version does not support the ConfigDelivery service. You can determine whether the method will succeed by calling config_delivery_available?.

About ConfigDelivery

ConfigDelivery service manages the deployment of kubernetes configuration to a fleet of kubernetes clusters.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object)

    A client object for the specified version.



73
74
75
76
77
78
79
80
81
82
# File 'lib/google/cloud/config_delivery.rb', line 73

def self.config_delivery version: :v1, &block
  require "google/cloud/config_delivery/#{version.to_s.downcase}"

  package_name = Google::Cloud::ConfigDelivery
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::ConfigDelivery.const_get(package_name).const_get(:ConfigDelivery)
  service_module.const_get(:Client).new(&block)
end

.config_delivery_available?(version: :v1) ⇒ boolean

Determines whether the ConfigDelivery service is supported by the current client. If true, you can retrieve a client object by calling config_delivery. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ConfigDelivery service, or if the versioned client gem needs an update to support the ConfigDelivery service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (boolean)

    Whether the service is available.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/google/cloud/config_delivery.rb', line 95

def self.config_delivery_available? version: :v1
  require "google/cloud/config_delivery/#{version.to_s.downcase}"
  package_name = Google::Cloud::ConfigDelivery
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::ConfigDelivery.const_get package_name
  return false unless service_module.const_defined? :ConfigDelivery
  service_module = service_module.const_get :ConfigDelivery
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.configure {|::Google::Cloud.configure.config_delivery| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-config_delivery library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



139
140
141
142
143
# File 'lib/google/cloud/config_delivery.rb', line 139

def self.configure
  yield ::Google::Cloud.configure.config_delivery if block_given?

  ::Google::Cloud.configure.config_delivery
end